@@ -2,9 +2,7 @@
 use strict;
 use warnings;
 
-use Algorithm::Combinatorics qw(variations_with_repetition);
 use MIDI::Drummer::Tiny;
-use MIDI::Util qw(dura_size);
 
 my $bpm = shift || 100;
 
