@@ -3,8 +3,10 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2004';
+our $VERSION = '0.2005';
 
+use Algorithm::Combinatorics qw(variations_with_repetition);
+use MIDI::Util qw(dura_size);
 use Music::Duration;
 
 use Moo;
@@ -463,7 +465,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2004
+version 0.2005
 
 =head1 SYNOPSIS
 
@@ -859,11 +861,9 @@ distribution.
 
 L<Algorithm::Combinatorics>
 
-L<MIDI::Util>
-
 L<Math::Bezier>
 
-L<MIDI::Simple>
+L<MIDI::Util>
 
 L<Moo>
 
